@@ -7,8 +7,9 @@
 #' @param filename An import file name.
 #' @importFrom tibble rowid_to_column
 #' @return A tibble, data frame variant with survey attributes.
-#' @importFrom fs path_ext_remove path_file
+#' @importFrom fs path_ext_remove path_file is_file
 #' @importFrom labelled var_label
+#' @importFrom purrr safely
 #' @family import functions
 #' @examples
 #' path <-  system.file("examples", "ZA7576.rds", package = "retroharmonize")
@@ -23,10 +24,25 @@ read_rds <- function(file,
                      filename = NULL, 
                      doi = NULL) {
   
-  if (! file.exists(file) ) stop ("The file does not exist.")
+  assertthat::assert_that(
+    fs::is_file(file),
+    msg =  paste0("file='", file, "' is not a file. ")
+  )
+  
   filename <- fs::path_file(file)
   
-  tmp <- readRDS (file = file) 
+  safely_readRDS <- purrr::safely ( readRDS )
+  
+  tmp <- safely_readRDS (file = file)  
+  
+  if ( ! is.null(tmp$error) ) {
+    warning ( tmp$error, "\nReturning an empty survey." )
+    return(
+      survey ( data.frame(), id="Could not read file", filename=filename, doi=doi)
+    )
+  } else {
+    tmp  <- tmp$result
+  }
   
   if ( ! "rowid" %in% names(tmp) )
     tmp <- tibble::rowid_to_column(tmp)
